/* beam0-pared.pov
 * Persistence of Vision Ray Tracer scene description file
 *
 * A beam of white light across a room, dispersed through 2 crown glass prisms,
 * and cast on the opposite wall.
 * Note: the dispersion value used is exaggerated 10X over the const.inc value.
 *
 * Copyright © 2005, 2017 Richard Callwood III.  All rights reserved.
 *
 * 2005-Jul-02  Created on or before as beam0.pov; prisms are in the center of
 *              the room.
 * 2005-Jul-08  The prisms are modified:
 *               - They are moved closer to the light source.
 *               - Dispersion samples is increased.
 *               - Photons pass_through is turned off and reflection is turned
 *                 on.
 * 2017-Jul-02  #version is added and the common.inc compatibility flag is set.
 * 2017-Jul-02  Photon media is increased for a smoother result; and media anti-
 *              aliasing is lowered to reduce render time.
 * 2017-Jul-02  Collect on is set on the prisms, in accordance with experience
 *              with media photons in BeamTest using v3.7.
 * 2017-Jul-05f  The scene file is copied to beam0-pared.com, stripped down,
 *              and made stand-alone for media photons debugging in v3.7.
 */
// +w700 +h490 +kff2
#version 3.6;

#declare R_ROOM = 10;
#declare H_ROOM = 6;
#declare ROOM_ILLUM = rgb 1;
#declare R_ILLUM = 0.1;
#declare SUPER_WHITE = 3;
#declare R_BEAM = 0.1;
#declare L_POINTER = 1;

global_settings
{  assumed_gamma 1
   max_trace_level 50
   photons { spacing 0.01 media 400 autostop 0 }
}

#declare t_Glow = texture
{  pigment { rgb 1 }
   finish { diffuse 0 ambient SUPER_WHITE }
}

union
{  box
   {  -1, 1 scale <R_ROOM, H_ROOM, R_ROOM> hollow
      pigment { rgb 1 }
   }
   light_source
   {  (H_ROOM - 2 * R_ILLUM) * y, ROOM_ILLUM
      fade_power 2 fade_distance H_ROOM
      spotlight point_at 0 radius 75 falloff 90
      #if (frame_number != 2)
         looks_like
         {  sphere { 0, R_ILLUM texture { t_Glow pigment { ROOM_ILLUM } } }
         }
      #end
      photons { reflection off refraction off  }
      media_interaction off
   }
   translate (1 - R_ROOM) * z
}

camera
{  ultra_wide_angle
   angle 60
   look_at 0
   location 2 * (1 - R_ROOM) * z
   right x * image_width
   up y * image_height
}

#declare RMajor = 1.5 * R_BEAM;
#declare rMinor = 0.5 * R_BEAM;
#declare HalfLPtr = L_POINTER / 2;
#declare Pointer = union
{  difference
   {  union
      {  cylinder { -x, x, RMajor + rMinor scale <HalfLPtr - rMinor, 1, 1> }
         cylinder { -x, x, RMajor scale <HalfLPtr, 1, 1> }
         torus { RMajor, rMinor rotate 90 * z translate (HalfLPtr - rMinor) * x }
         torus { RMajor, rMinor rotate 90 * z translate (rMinor - HalfLPtr) * x }
         texture
         {  pigment { rgb <0.96, 0.95, 0.92> }
            finish
            {  reflection { 0.4 metallic }
               diffuse 0.36 ambient 0.06
               specular 1 metallic 0.95
               roughness 0.018377
               brilliance 3.8
            }
         }
      }
      cylinder
      {  -0.1 * L_POINTER * x, 0.51 * L_POINTER * x, R_BEAM * 1.001
         texture { t_Glow }
      }
   }
   light_source
   {  0, rgb SUPER_WHITE
      cylinder parallel point_at x radius R_BEAM * 0.75 falloff R_BEAM
   }
}

object { Pointer translate <HalfLPtr - R_ROOM, 0, 0> }

#declare Media = media
{ scattering { 1, 1 extinction 0 }
  method 3
  intervals 1
  samples 3, 3
  aa_level 2
}

box
{  -1, 1 scale <R_ROOM + 0.1, H_ROOM, R_BEAM> hollow
   pigment { rgbt 1 }
   photons { pass_through }
   interior { media { Media } }
}

#declare Prism = prism
{  -1, 1, 4, <0, 1>, <1, -1>, <-1, -1>, <0, 1> hollow
   rotate -90 * x
   scale <1, 1, 2 * R_BEAM>
   pigment { rgbt 1 }
   finish
   {  specular 1 roughness 0.001
      reflection { 0, 1 fresnel } conserve_energy
   }
   interior
   {  ior 1.52 dispersion 1.12 dispersion_samples 16
      media { Media }
   }
   photons { target collect on refraction on reflection on }
}

object { Prism rotate 180 * z translate <-4.8, 0.2, 0> }
object { Prism translate <-3.2, 0.6, 0> }
